==> haskell-graphite-0.10.0.1-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-IxI9C70f3iq66CBpIkqHyq
key:                  graphite-0.10.0.1-IxI9C70f3iq66CBpIkqHyq
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  29dd1dba15454103a7eaf8828a3f8786
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-IxI9C70f3iq66CBpIkqHyq
depends:
    QuickCheck-2.14.3-1v0srcb4FkGBzkvUbxpBuR base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-Glq4i28JePC4SrwZhjXu49
    containers-0.6.7 deepseq-1.4.8.0
    graphviz-2999.20.2.1-AXh57srZqVs7Y102KGcY2z
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb process-1.6.18.0
    random-1.2.1.3-AojK1F3ExhxDorHTlNe3sA text-2.0.2
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphite-0.10.0.1-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-IQNSkYT8SHs3Q1yV8anjXX
key:                  graphite-0.10.0.1-IQNSkYT8SHs3Q1yV8anjXX
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  58269852f588a265f20d21598d2e328f
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-IQNSkYT8SHs3Q1yV8anjXX
depends:
    QuickCheck-2.14.3-I4jvyhzMsvKgXCQyl85qk base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-BNDoLN1lMf8AZ6wmPn3FqZ
    containers-0.6.7 deepseq-1.4.8.0
    graphviz-2999.20.2.1-6DhjXdRJvr25PweP76n81b
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac process-1.6.18.0
    random-1.2.1.3-8yAn85BRVsALc4v1F70S7L text-2.0.2
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
